import '../assets/css/sdpi.css';
import '../assets/css/styles.css';
import { default as EventEmitter } from 'eventemitter3';
import Details from "./elements/Details";
import HtmlElementInterface from "./HtmlElementInterface";
import ElementGroupInterface from './ElementGroupInterface';
import ElementInterface from './ElementInterface';
import Dropdown from './elements/Dropdown';
import Input from './elements/Input';
import { EventType } from './EventType';
import { FormDataType } from './FormDataType';
export default class FormBuilder<T extends FormDataType> {
    private readonly initialData;
    private elementBag;
    private eventEmitter;
    constructor(initialData: T);
    /**
     * Returns the currently set formdata (or settings) as an object
     */
    getFormData(): T;
    /**
     * Allows to overwrite the formdata with whatever is passed
     */
    setFormData(data: T): void;
    /**
     * Builds the form and appends all its elements to the passed html element
     */
    appendTo(element: HTMLElement): void;
    /**
     * Adds a new form element to the form
     * @param {string} name
     * @param value A element or a group of elements (created by the create* methods)
     */
    addElement<K extends keyof T>(name: K, value: T[K] extends Record<string, string> ? ElementGroupInterface & {
        elements: {
            [x in keyof T[K]]: ElementInterface;
        };
    } : ElementInterface): void;
    /**
     * Allows to add an arbitrary object that returns a html element which then will be added to the form.
     * @param {HtmlElementInterface} element
     */
    addHtml(element: HtmlElementInterface): void;
    /**
     * Adds a simple HTMLElement to the form
     */
    addHtmlElement(element: HTMLElement): void;
    /** Creates a text input element */
    createInput(): Input;
    /** Creates a drowpdown (or select) element */
    createDropdown(): Dropdown;
    /** Creates a collapsible detail element to output informational text */
    createDetails(): Details;
    /**
     * Allows to attach an eventlistener to formbuilder events
     * @param {'change-settings' | 'click-link'} event
     * @param callback The function that will get called once the event occurs
     */
    on<K extends keyof Pick<EventType, 'change-settings' | 'click-link'>>(event: K, callback: EventEmitter.EventListener<EventType, K>): void;
    private addEventsToElement;
    private onChangeElementValue;
}
